@@ -1,5 +1,5 @@
 ### R code from vignette source 'gdistance1.Rnw'
-### Encoding: ISO8859-1
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: gdistance1.Rnw:125-126
@@ -56,6 +56,7 @@ options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)
 ### code chunk number 4: gdistance-1
 ###################################################
 library("gdistance")
+set.seed(123)
 r <- raster(ncol=3,nrow=3)
 r[] <- 1:ncell(r)
 r
@@ -64,14 +65,14 @@ r
 ###################################################
 ### code chunk number 5: figure1
 ###################################################
-plot(r, main="r")
+plot(r, main="r", xlab="Longitude (degrees)", ylab="Latitude (degrees)")
 text(r)
 
 
 ###################################################
 ### code chunk number 6: gdistance-2
 ###################################################
-plot(r, main="r")
+plot(r, main="r", xlab="Longitude (degrees)", ylab="Latitude (degrees)")
 text(r)
 
 
@@ -129,14 +130,15 @@ print(image(transitionMatrix(tr1)))
 ###################################################
 ### code chunk number 14: figure3
 ###################################################
-plot(raster(tr3), main="raster(tr3)")
+plot(raster(tr3), main="raster(tr3)", xlab="Longitude (degrees)", 
+     ylab="Latitude (degrees)")
 
 
 ###################################################
 ### code chunk number 15: gdistance-9
 ###################################################
-tr1C <- geoCorrection(tr1, type="c", multpl=FALSE)
-tr2C <- geoCorrection(tr2, type="c", multpl=FALSE)
+tr1C <- geoCorrection(tr1, type="c")
+tr2C <- geoCorrection(tr2, type="c")
 
 
 ###################################################
@@ -159,7 +161,7 @@ tr3R <- tr3 * CorrMatrix
 ###################################################
 ### code chunk number 18: gdistance-12
 ###################################################
-sP <- cbind(c(-100, 100, -100), c(-50, 50, 50))
+sP <- cbind(c(-100, -100, 100), c(50, -50, 50))
 
 
 ###################################################
@@ -174,20 +176,25 @@ rSPDistance(tr3R, sP, sP, theta=1e-12, totalNet="total")
 ### code chunk number 20: gdistance-14
 ###################################################
 origin <- SpatialPoints(cbind(0, 0))
-rSPraster <- passage(tr3C, origin, sP[3,], theta=3)
+rSPraster <- passage(tr3C, origin, sP[1,], theta=3)
 
 
 ###################################################
 ### code chunk number 21: figure4
 ###################################################
-plot(rSPraster, main="rSPraster")
+par(mar=c(5, 4, 2, 6) + 0.1)
+image(rSPraster, main="rSPraster", col=rev(terrain.colors(255)), xlab="Longitude (degrees)", ylab="Latitude (degrees)")
+plot(rSPraster, horizontal=FALSE, smallplot=c(.83, .845, .3, .8), 
+  legend.only=TRUE, legend.lab="Net passages")
+text(sP[1,1]+7, sP[1,2]-10, "sP1")
+text(10, 0, "O")
 
 
 ###################################################
 ### code chunk number 22: gdistance-15
 ###################################################
 r1 <- passage(tr3C, origin, sP[1,], theta=1)
-r2 <- passage(tr3C, origin, sP[3,], theta=1)
+r2 <- passage(tr3C, origin, sP[2,], theta=1)
 rJoint <- min(r1, r2)
 rDiv <- max(max(r1, r2) * (1 - min(r1, r2)) - min(r1, r2), 0) 
 
@@ -195,13 +202,25 @@ rDiv <- max(max(r1, r2) * (1 - min(r1, r2)) - min(r1, r2), 0)
 ###################################################
 ### code chunk number 23: figure5
 ###################################################
-plot(rJoint, main="rJoint")
+par(mar=c(5, 4, 2, 6) + 0.1)
+image(rJoint, main="rJoint", col=rev(terrain.colors(255)), xlab="Longitude (degrees)", ylab="Latitude (degrees)")
+plot(rDiv, horizontal=FALSE, smallplot=c(.83, .845, .3, .8), 
+  legend.only=TRUE, legend.lab="Degree of overlap")
+text(sP[1,1]+7, sP[1,2]-10, "sP1")
+text(sP[2,1]+7, sP[2,2]-10, "sP2")
+text(10, 0, "O")
 
 
 ###################################################
 ### code chunk number 24: figure6
 ###################################################
-plot(rDiv, main="rDiv")
+par(mar=c(5, 4, 2, 6) + 0.1)
+image(rDiv, main="rDiv", col=rev(terrain.colors(255)), xlab="Longitude (degrees)", ylab="Latitude (degrees)")
+plot(rDiv, horizontal=FALSE, smallplot=c(.83, .845, .3, .8), 
+  legend.only=TRUE, legend.lab="Degree of non-overlap")
+text(sP[1,1]+7, sP[1,2]-10, "sP1")
+text(sP[2,1]+7, sP[2,2]-10, "sP2")
+text(10, 0, "O")
 
 
 ###################################################
@@ -213,27 +232,31 @@ pathInc(tr3C, origin, sP)
 ###################################################
 ### code chunk number 26: figure7
 ###################################################
-plot(function(x)6 * exp(-3.5 * abs(x + 0.05)), -1, 1, xlab="slope", ylab="speed (m/s)")
+plot(function(x)6 * exp(-3.5 * abs(x + 0.05)), -1, 1, xlab=expression(Slope~italic(m)), ylab=expression(Speed~italic(s)~~(m/s)))
 lines(cbind(c(0,0),c(0,6)), lty="longdash")
 
 
 ###################################################
 ### code chunk number 27: gdistance-18
 ###################################################
-r <- raster(system.file("external/maungawhau.grd", 
-  package="gdistance"))
+r <- raster(system.file("external/maungawhau.grd", package="gdistance"))
 
 
 ###################################################
 ### code chunk number 28: gdistance-19
 ###################################################
 altDiff <- function(x){x[2] - x[1]}
-hd <- transition(r,altDiff,8,symm=FALSE)
-slope <- geoCorrection(hd, scl=FALSE)
+hd <- transition(r, altDiff, 8, symm=FALSE)
 
 
 ###################################################
-### code chunk number 29: gdistance-20
+### code chunk number 29: gdistance-19
+###################################################
+slope <- geoCorrection(hd)
+
+
+###################################################
+### code chunk number 30: gdistance-20
 ###################################################
 adj <- adjacent(r, cells=1:ncell(r), pairs=TRUE, directions=8)
 speed <- slope
@@ -241,24 +264,25 @@ speed[adj] <- 6 * exp(-3.5 * abs(slope[adj] + 0.05))
 
 
 ###################################################
-### code chunk number 30: gdistance-21
+### code chunk number 31: gdistance-21
 ###################################################
-x <- geoCorrection(speed, scl=FALSE) 
+Conductance <- geoCorrection(speed) 
 
 
 ###################################################
-### code chunk number 31: gdistance-22
+### code chunk number 32: gdistance-22
 ###################################################
 A <- c(2667670, 6479000)
 B <- c(2667800, 6479400)
-AtoB <- shortestPath(x, A, B, output="SpatialLines")
-BtoA <- shortestPath(x, B, A, output="SpatialLines")
+AtoB <- shortestPath(Conductance, A, B, output="SpatialLines")
+BtoA <- shortestPath(Conductance, B, A, output="SpatialLines")
 
 
 ###################################################
-### code chunk number 32: fig8plot
+### code chunk number 33: fig8plot
 ###################################################
-plot(r, main="")
+plot(r, xlab="x coordinate (m)", ylab="y coordinate (m)",
+     legend.lab="Altitude (masl)")
 lines(AtoB, col="red", lwd=2)
 lines(BtoA, col="blue")
 text(A[1] - 10, A[2] - 10, "A")
@@ -266,9 +290,12 @@ text(B[1] + 10, B[2] + 10, "B")
 
 
 ###################################################
-### code chunk number 33: fig8
+### code chunk number 34: fig8
 ###################################################
-plot(r, main="")
+par(mar=c(4, 4, 1, 6) + 0.1)
+image(r, main="", col=rev(terrain.colors(255)), xlab="x coordinate (m)", ylab="y coordinate (m)")
+plot(r, horizontal=FALSE, smallplot=c(.83, .845, .2, .7), 
+  legend.only=TRUE, legend.lab="Altitude (masl)")
 lines(AtoB, col="red", lwd=2)
 lines(BtoA, col="blue")
 text(A[1] - 10, A[2] - 10, "A")
@@ -276,7 +303,7 @@ text(B[1] + 10, B[2] + 10, "B")
 
 
 ###################################################
-### code chunk number 34: gdistance-24
+### code chunk number 35: gdistance-24
 ###################################################
 Europe <- raster(system.file("external/Europe.grd", 
   package="gdistance"))
@@ -287,14 +314,15 @@ pC <- as.matrix(popCoord[c("x","y")])
 
 
 ###################################################
-### code chunk number 35: gdistance1.Rnw:730-732
+### code chunk number 36: gdistance1.Rnw:772-775
 ###################################################
-plot(Europe, main="")
+plot(Europe, main="", xlab="Longitude (degrees)", ylab="Latitude (degrees)",
+     legend=FALSE)
 text(pC[,1],pC[,2],unlist(popCoord["Population"]),cex=.7)
 
 
 ###################################################
-### code chunk number 36: gdistance-25
+### code chunk number 37: gdistance-25
 ###################################################
 geoDist <- pointDistance(pC, longlat=TRUE)
 geoDist <- as.dist(geoDist)
@@ -310,7 +338,7 @@ cor(genDist,resDist)
 
 
 ###################################################
-### code chunk number 37: gdistance-26
+### code chunk number 38: gdistance-26
 ###################################################
 origin <- unlist(popCoord[22,c("x","y")])
 pI <- pathInc(trC, origin=origin, from=pC, 
